@@ -1,4 +1,3 @@
-use futures::stream::StreamExt;
 use helium_api::{models::QueryTimeRange, validators, Client, IntoVec};
 
 #[tokio::main]
@@ -19,13 +18,15 @@ async fn main() -> Result<(), Box<dyn std::error::Error>> {
             min_time: "-30 day".into(),
             max_time: "-1 hour".into(),
         };
-        let mut stream = validators::rewards(&client, &v.address, &params).await;
-        while let Some(r) = stream.next().await {
-            match r {
-                Ok(r) => println!("{:?}", r),
-                Err(e) => println!("Error trying to get helium rewards: {}", e),
-            }
-        }
+        println!("Validator: {:?}", v);
+        let rewards = validators::rewards(&client, &v.address, &params)
+            .into_vec()
+            .await?;
+        println!("Last 10 rewards:");
+        rewards
+            .iter()
+            .take(10)
+            .for_each(|r| println!("Block: {}: {} HNT", r.block, r.amount.to_string()));
     };
 
     Ok(())
