@@ -1,12 +1,6 @@
-use crate::*;
-use serde::Deserialize;
+use crate::{models::PendingTxnStatus, *};
 use serde_json::json;
 
-#[derive(Clone, Deserialize, Debug)]
-pub struct PendingTxnStatus {
-    pub hash: String,
-}
-
 /// Convert a given transaction to json, ready to be submitted
 /// Submit a transaction to the blockchain
 pub async fn submit<T>(client: &Client, txn: T) -> Result<PendingTxnStatus>
