@@ -26,6 +26,6 @@ pub async fn stats(client: &Client) -> Result<ValidatorStats> {
 /// for a given timeframe. `QueryTimeRange` contains the timestamps given in
 /// 4ISO 8601 format, or in relative time. The block that contains the max_time
 /// timestamp is excluded from the result.
-pub async fn rewards(client: &Client, address: &str, query: &QueryTimeRange) -> Stream<Reward> {
+pub fn rewards(client: &Client, address: &str, query: &QueryTimeRange) -> Stream<Reward> {
     client.fetch_stream(&format!("/validators/{}/rewards", address), query)
 }
